/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 * 
 * $Id: CoComposeActionBarContributor.java,v 1.3 2004/04/28 16:30:08 dwagelaa Exp $
 * $Log: CoComposeActionBarContributor.java,v $
 * Revision 1.3  2004/04/28 16:30:08  dwagelaa
 * rearranged EPS export under ExportAction
 *
 * Revision 1.2  2004/04/27 16:43:58  dwagelaa
 * + added drag-n-drop
 * + added copy/paste
 * + added general copying operation
 * - removed examples (in separate module now)
 *
 */

package be.ac.vub.cocompose.eclipse.actions;

import org.eclipse.draw2d.PositionConstants;
import org.eclipse.gef.ui.actions.ActionBarContributor;
import org.eclipse.gef.ui.actions.AlignmentRetargetAction;
import org.eclipse.gef.ui.actions.CopyRetargetAction;
import org.eclipse.gef.ui.actions.DeleteRetargetAction;
import org.eclipse.gef.ui.actions.GEFActionConstants;
import org.eclipse.gef.ui.actions.PasteRetargetAction;
import org.eclipse.gef.ui.actions.RedoRetargetAction;
import org.eclipse.gef.ui.actions.UndoRetargetAction;
import org.eclipse.gef.ui.actions.ZoomComboContributionItem;
import org.eclipse.gef.ui.actions.ZoomInRetargetAction;
import org.eclipse.gef.ui.actions.ZoomOutRetargetAction;
import org.eclipse.jface.action.IMenuManager;
import org.eclipse.jface.action.IToolBarManager;
import org.eclipse.jface.action.MenuManager;
import org.eclipse.jface.action.Separator;
import org.eclipse.ui.IWorkbenchActionConstants;

/**
 * Eclipse editor action bar.
 * @author Dennis Wagelaar
 * @version 0.2.9, 27/04/2004
 * @since 0.2.0
 */
public class CoComposeActionBarContributor extends ActionBarContributor
{
  /**
   * @see org.eclipse.gef.ui.actions.ActionBarContributor#buildActions()
   */
  protected void buildActions()
  {
    addRetargetAction(new UndoRetargetAction());
    addRetargetAction(new RedoRetargetAction());
    addRetargetAction(new DeleteRetargetAction());
    addRetargetAction(new CopyRetargetAction());
    addRetargetAction(new PasteRetargetAction());
  
    addRetargetAction(new AlignmentRetargetAction(PositionConstants.LEFT));
    addRetargetAction(new AlignmentRetargetAction(PositionConstants.CENTER));
    addRetargetAction(new AlignmentRetargetAction(PositionConstants.RIGHT));
    addRetargetAction(new AlignmentRetargetAction(PositionConstants.TOP));
    addRetargetAction(new AlignmentRetargetAction(PositionConstants.MIDDLE));
    addRetargetAction(new AlignmentRetargetAction(PositionConstants.BOTTOM));
  
    addRetargetAction(new ZoomInRetargetAction());
    addRetargetAction(new ZoomOutRetargetAction());
    
    addRetargetAction(new ExportRetargetAction());
  }

  /**
   * @see org.eclipse.gef.ui.actions.ActionBarContributor#declareGlobalActionKeys()
   */
  protected void declareGlobalActionKeys()
  {
    addGlobalActionKey(IWorkbenchActionConstants.PRINT);
  }

  /**
   * @see org.eclipse.ui.part.EditorActionBarContributor#contributeToToolBar(IToolBarManager)
   */
  public void contributeToToolBar(IToolBarManager tbm) 
  {
    tbm.add(getAction(IWorkbenchActionConstants.UNDO));
    tbm.add(getAction(IWorkbenchActionConstants.REDO));
  
    tbm.add(new Separator());
    tbm.add(getAction(GEFActionConstants.ALIGN_LEFT));
    tbm.add(getAction(GEFActionConstants.ALIGN_CENTER));
    tbm.add(getAction(GEFActionConstants.ALIGN_RIGHT));
    tbm.add(new Separator());
    tbm.add(getAction(GEFActionConstants.ALIGN_TOP));
    tbm.add(getAction(GEFActionConstants.ALIGN_MIDDLE));
    tbm.add(getAction(GEFActionConstants.ALIGN_BOTTOM));
  
    tbm.add(new Separator());
    tbm.add(new ZoomComboContributionItem(getPage()));
  }

  /**
   * @see org.eclipse.ui.part.EditorActionBarContributor#contributeToMenu(IMenuManager)
   */
  public void contributeToMenu(IMenuManager menubar) 
  {
    super.contributeToMenu(menubar);
    MenuManager modelMenu = new MenuManager("&Model");
    modelMenu.add(getAction(GEFActionConstants.EXPORT));
    menubar.insertAfter(IWorkbenchActionConstants.M_EDIT, modelMenu);
    MenuManager viewMenu = new MenuManager("&View");
    viewMenu.add(getAction(GEFActionConstants.ZOOM_IN));
    viewMenu.add(getAction(GEFActionConstants.ZOOM_OUT));
    menubar.insertAfter(IWorkbenchActionConstants.M_EDIT, viewMenu);
  }
}
