/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 * 
 * $Id: CoComposeCopyAction.java,v 1.2 2004/04/28 12:24:36 dwagelaa Exp $
 * $Log: CoComposeCopyAction.java,v $
 * Revision 1.2  2004/04/28 12:24:36  dwagelaa
 * worked on drag-n-drop
 * updated copy/paste
 * updated deep copy operation
 *
 * Revision 1.1  2004/04/27 16:43:58  dwagelaa
 * + added drag-n-drop
 * + added copy/paste
 * + added general copying operation
 * - removed examples (in separate module now)
 *
 */

package be.ac.vub.cocompose.eclipse.actions;

import java.util.List;
import java.util.Vector;

import org.eclipse.gef.EditPart;
import org.eclipse.gef.internal.GEFMessages;
import org.eclipse.gef.ui.actions.Clipboard;
import org.eclipse.gef.ui.actions.GEFActionConstants;
import org.eclipse.gef.ui.actions.SelectionAction;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.ui.IWorkbenchPart;

import be.ac.vub.cocompose.lang.core.ModelElement;

/**
 * Copies CoCompose model elements.
 * @author Dennis Wagelaar
 * @version 0.2.9, 28/04/2004
 * @since 0.2.9
 * be.ac.vub.cocompose.eclipse.actions.CoComposePasteAction
 */
public class CoComposeCopyAction extends SelectionAction
{
  private Object template = null;
  
  /**
   * Creates a CoComposeCopyAction.
   * @param part the CoCompose editor part.
   */
  public CoComposeCopyAction(IWorkbenchPart part)
  {
    super(part);
  }

  /**
   * @see org.eclipse.gef.Disposable#dispose()
   */
  public void dispose() 
  {
    template = null;
  }

  /**
   * Sets the default {@link Clipboard Clipboard's} contents to be the
   * currently selected template.
   */
  public void run() 
  {
    Clipboard.getDefault().setContents(template);
  }

  /**
   * @see org.eclipse.gef.ui.actions.WorkbenchPartAction#init()
   */
  protected void init() 
  {
    setId(GEFActionConstants.COPY);
    setText(GEFMessages.CopyAction_Label);
    setToolTipText(GEFMessages.CopyAction_Tooltip);
  }

  /**
   * @see org.eclipse.gef.ui.actions.WorkbenchPartAction#calculateEnabled()
   */
  protected boolean calculateEnabled()
  {
    return (template != null);
  }

  /**
   * @see org.eclipse.gef.ui.actions.SelectionAction#handleSelectionChanged()
   */
  protected void handleSelectionChanged()
  {
    ISelection s = getSelection();
    if (!(s instanceof IStructuredSelection))
      return;
    IStructuredSelection selection = (IStructuredSelection) s;
    template = null;
    List toclip = new Vector();
    List elements = selection.toList();
    for (int i = 0; i < elements.size(); i++)
    {
      Object obj = elements.get(i);
      if (obj instanceof EditPart) 
      {
        Object model = ((EditPart) obj).getModel();
        if (model instanceof ModelElement)
        { //copy only non-root elements
          if (((ModelElement) model).getNamespace() != null)
            toclip.add(model);
        }
      }
    }
    // remove child entries 
    List remove = new Vector();
    for (int i = 0; i < toclip.size(); i++)
    {
      ModelElement element = (ModelElement) toclip.get(i);
      if (toclip.contains(element.getNamespace()))
        remove.add(element);
    }
    toclip.removeAll(remove);
    if (!toclip.isEmpty())
      template = toclip;
    refresh();
  }
}
