/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 * 
 * $Id: CoComposePasteTemplateAction.java,v 1.2 2004/04/27 16:43:58 dwagelaa Exp $
 * $Log: CoComposePasteTemplateAction.java,v $
 * Revision 1.2  2004/04/27 16:43:58  dwagelaa
 * + added drag-n-drop
 * + added copy/paste
 * + added general copying operation
 * - removed examples (in separate module now)
 *
 */

package be.ac.vub.cocompose.eclipse.actions;

import org.eclipse.draw2d.geometry.Point;
import org.eclipse.gef.EditPart;
import org.eclipse.gef.commands.Command;
import org.eclipse.gef.internal.GEFMessages;
import org.eclipse.gef.requests.CreateRequest;
import org.eclipse.gef.requests.CreationFactory;
import org.eclipse.gef.ui.actions.Clipboard;
import org.eclipse.gef.ui.actions.GEFActionConstants;
import org.eclipse.gef.ui.actions.SelectionAction;
import org.eclipse.ui.IWorkbenchPart;

import be.ac.vub.cocompose.CoCompose;
import be.ac.vub.cocompose.eclipse.CoComposeElementFactory;

/**
 * GEF {@link org.eclipse.gef.ui.actions.Clipboard} paste handler
 * for CoCompose elements.
 * @author Dennis Wagelaar
 * @version 0.2.9, 27/04/2004
 * @since 0.2.8
 */
public class CoComposePasteTemplateAction extends SelectionAction
{
  private CreateRequest request;

  /**
   * Creates a new CoComposePasteTemplateAction.
   * @param part the CoCompose editor.
   */
  public CoComposePasteTemplateAction(IWorkbenchPart part)
  {
    super(part);
  }

  /**
   * @see org.eclipse.gef.ui.actions.WorkbenchPartAction#calculateEnabled()
   */
  protected boolean calculateEnabled()
  {
    Command command = createPasteCommand();
    return (getClipboardContents() != null && 
            command != null && command.canExecute());
  }

  /**
   * Creates and returns a command (which may be <code>null</code>)
   * to create a new EditPart based on the template on the clipboard.
   * @return the paste command
   */
  protected Command createPasteCommand() 
  {
    if (getSelectedObjects() == null || getSelectedObjects().isEmpty())
      return null;
    CreateRequest request = new CreateRequest();
    request.setFactory(getFactory(getClipboardContents()));
    request.setLocation(getPasteLocation());
    Object obj = getSelectedObjects().get(0);
    if (obj instanceof EditPart)
      return ((EditPart) obj).getCommand(request);
    return null;
  }

  /**
   * Returns the contents of the default GEF {@link Clipboard}.
   * @return the clipboard's contents
   */
  protected Object getClipboardContents() 
  {
    return Clipboard.getDefault().getContents();
  }

  /**
   * Returns the appropriate Factory object to be used for the specified 
   * template. This Factory is used on the CreateRequest that is sent to the 
   * target EditPart.
   * @param template the template Object
   * @return a Factory
   */
  protected CreationFactory getFactory(Object template) 
  {
    return new CoComposeElementFactory(
      CoCompose.getDefault().getFactory(), 
      template);
  }

  /**
   * Get the location where to paste.
   * @return the location where to paste.
   */
  protected Point getPasteLocation()
  {
    return new Point(10, 10);
  }

  /**
   * @see org.eclipse.gef.ui.actions.EditorPartAction#init()
   */
  protected void init() 
  {
    setId(GEFActionConstants.PASTE);
    setText(GEFMessages.PasteAction_Label);
    setToolTipText(GEFMessages.PasteAction_Tooltip);
  }

  /**
   * Executes the command returned by {@link #createPasteCommand()}.
   */
  public void run() 
  {
    execute(createPasteCommand());
  }
}
