/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 * 
 * $Id: CreateAction.java,v 1.3 2004/04/27 16:43:58 dwagelaa Exp $
 * $Log: CreateAction.java,v $
 * Revision 1.3  2004/04/27 16:43:58  dwagelaa
 * + added drag-n-drop
 * + added copy/paste
 * + added general copying operation
 * - removed examples (in separate module now)
 *
 */

package be.ac.vub.cocompose.eclipse.actions;

import java.util.List;

import org.eclipse.core.internal.runtime.Assert;
import org.eclipse.gef.EditPart;
import org.eclipse.gef.commands.Command;
import org.eclipse.gef.ui.actions.SelectionAction;
import org.eclipse.ui.IWorkbenchPart;

import be.ac.vub.cocompose.eclipse.commands.CreateCommand;
import be.ac.vub.cocompose.lang.ModelFactory;
import be.ac.vub.cocompose.lang.core.Namespace;

/**
 * Abstract property creation action for the selected element.
 * @author Dennis Wagelaar
 * @version 0.2.9, 27/04/2004
 * @since 0.2.0
 */
public abstract class CreateAction extends SelectionAction
{
  protected ModelFactory factory;
  private Class elementClass;

  /**
   * Creates a CreateSolutionPatternAction.
   * @param editor the CoCompose editor.
   */
  public CreateAction(IWorkbenchPart editor, ModelFactory factory, Class elementClass)
  {
    super(editor);
    Assert.isNotNull(factory);
    Assert.isNotNull(elementClass);
    this.factory = factory;
    this.elementClass = elementClass;
  }

  /**
   * @see org.eclipse.jface.action.IAction#run()
   */
  public void run()
  {
    execute(getCommand());
  }

  /**
   * @see org.eclipse.gef.ui.actions.EditorPartAction#calculateEnabled()
   */
  protected boolean calculateEnabled()
  {
    List parts = getSelectedObjects();
    if (parts.size() != 1)
      return false;
    Object o = parts.get(0);
    if (!(o instanceof EditPart))
        return false;
    EditPart part = (EditPart) o;
    if (!(part.getModel() instanceof Namespace))
      return false;
    if (!(elementClass.isInstance(part.getModel())))
      return false;
    return true;
  }

  /**
   * Creates the command to be executed.
   * @return the command.
   */
  protected Command getCommand()
  {
    EditPart part = (EditPart) getSelectedObjects().get(0);
    Namespace ns = (Namespace) part.getModel();
    CreateCommand cmd = new CreateCommand();
    cmd.setOwner(ns);
    return cmd;
  }
}
