/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 * 
 * $Id: CreateModelTransformationAction.java,v 1.1 2004/05/11 08:18:44 dwagelaa Exp $
 * $Log: CreateModelTransformationAction.java,v $
 * Revision 1.1  2004/05/11 08:18:44  dwagelaa
 * + added the ModelTransformation language element
 *
 */

package be.ac.vub.cocompose.eclipse.actions;

import org.eclipse.gef.commands.Command;
import org.eclipse.ui.IWorkbenchPart;

import be.ac.vub.cocompose.eclipse.CoComposeImages;
import be.ac.vub.cocompose.eclipse.commands.CreateCommand;
import be.ac.vub.cocompose.lang.ModelFactory;
import be.ac.vub.cocompose.lang.core.RefinedElement;

/**
 * Creates a ModelTransformation for the selected element.
 * @author Dennis Wagelaar
 * @version 0.2.10, 11/05/2004
 * @since 0.2.10
 */
public class CreateModelTransformationAction extends CreateAction
{
  public static final String ID = "CreateModelTransformation";

  /**
   * Creates a CreateModelTransformationAction.
   * @param editor the CoCompose editor.
   * @param factory the model element factory.
   */
  public CreateModelTransformationAction(
    IWorkbenchPart editor,
    ModelFactory factory)
  {
    super(editor, factory, RefinedElement.class);
    setText("Model transformation");
    setId(ID);
    setToolTipText("Creates a model transformation within the selected element");
    setImageDescriptor(CoComposeImages.MODEL_TRANS_OBJ);
  }

  /**
   * Creates the command to be executed.
   * @return the command.
   */
  protected Command getCommand()
  {
    CreateCommand cmd = (CreateCommand) super.getCommand();
    cmd.setElement(factory.createModelTransformation());
    return cmd;
  }
}
