/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.eclipse.editparts;

import org.eclipse.gef.EditPart;
import org.eclipse.gef.EditPartFactory;

import be.ac.vub.cocompose.lang.core.Concept;
import be.ac.vub.cocompose.lang.core.Model;
import be.ac.vub.cocompose.lang.core.Relationship;
import be.ac.vub.cocompose.lang.core.Role;

/**
 * Creates the Eclipse graphical editor CoCompose elements.
 * @author Dennis Wagelaar
 * @version 0.2.0, 03/12/2003
 * @since 0.2.0
 */
public class GraphicalPartFactory implements EditPartFactory
{
  /**
   * @see org.eclipse.gef.EditPartFactory#createEditPart(org.eclipse.gef.EditPart, java.lang.Object)
   */
  public EditPart createEditPart(EditPart context, Object model)
  {
    EditPart child = null;
    if (model instanceof Concept)
      child = new ConceptEditPart();
    else if (model instanceof Role)
      child = new RoleEditPart();
    else if (model instanceof Relationship)
      child = new RelationshipEditPart();
    else if (model instanceof Model)
      child = new ModelEditPart();
    child.setModel(model);
    return child;
  }
}
