/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.eclipse.editparts;

import java.beans.PropertyChangeEvent;

import org.eclipse.draw2d.AutomaticRouter;
import org.eclipse.draw2d.BendpointConnectionRouter;
import org.eclipse.draw2d.ColorConstants;
import org.eclipse.draw2d.ConnectionLayer;
import org.eclipse.draw2d.FanRouter;
import org.eclipse.draw2d.Figure;
import org.eclipse.draw2d.FreeformLayer;
import org.eclipse.draw2d.FreeformLayout;
import org.eclipse.draw2d.IFigure;
import org.eclipse.draw2d.MarginBorder;
import org.eclipse.gef.DragTracker;
import org.eclipse.gef.EditPolicy;
import org.eclipse.gef.LayerConstants;
import org.eclipse.gef.Request;
import org.eclipse.gef.editpolicies.RootComponentEditPolicy;
import org.eclipse.gef.requests.SelectionRequest;
import org.eclipse.gef.tools.DeselectAllTracker;
import org.eclipse.gef.tools.MarqueeDragTracker;

import be.ac.vub.cocompose.eclipse.editpolicies.CoComposeXYLayoutEditPolicy;
import be.ac.vub.cocompose.eclipse.model.core.EclipseModel;

/**
 * Eclipse editpart controller for EclipseModel objects.
 * @author Dennis Wagelaar
 * @version 0.2.0, 02/12/2003
 * @since 0.2.0
 */
public class ModelEditPart extends NamespaceEditPart implements LayerConstants
{
  /**
   * @see org.eclipse.gef.EditPart#getDragTracker(org.eclipse.gef.Request)
   */
  public DragTracker getDragTracker(Request req)
  {
    if (req instanceof SelectionRequest) 
      if (((SelectionRequest) req).getLastButtonPressed() == 3)
        return new DeselectAllTracker(this);
    return new MarqueeDragTracker();
  }

  /**
   * @see java.beans.PropertyChangeListener#propertyChange(java.beans.PropertyChangeEvent)
   */
  public void propertyChange(PropertyChangeEvent evt)
  {
    if (EclipseModel.ID_ROUTER.equals(evt.getPropertyName()))
      refreshVisuals();
    else
      super.propertyChange(evt);
  }

  /**
   * Installs EditPolicies specific to this.
   * @see org.eclipse.gef.editparts.AbstractEditPart#createEditPolicies()
   */
  protected void createEditPolicies()
  {
    super.createEditPolicies();
    installEditPolicy(EditPolicy.NODE_ROLE, null);
    installEditPolicy(EditPolicy.GRAPHICAL_NODE_ROLE, null);
    installEditPolicy(EditPolicy.SELECTION_FEEDBACK_ROLE, null);
    installEditPolicy(EditPolicy.COMPONENT_ROLE, new RootComponentEditPolicy());
    installEditPolicy(EditPolicy.LAYOUT_ROLE, new CoComposeXYLayoutEditPolicy());
  }

  /**
   * Gets the model associated with this.
   * @return the model of this.
   */
  protected EclipseModel getCoComposeModel()
  {
    return (EclipseModel) getModel();
  }

  /**
   * @see org.eclipse.gef.editparts.AbstractEditPart#refreshVisuals()
   */
  protected void refreshVisuals()
  {
    ConnectionLayer cLayer = (ConnectionLayer) getLayer(CONNECTION_LAYER);
//    if (getCoComposeModel().getConnectionRouter().equals(LogicDiagram.ROUTER_MANUAL)){
    AutomaticRouter router = new FanRouter();
    router.setNextRouter(new BendpointConnectionRouter());
    cLayer.setConnectionRouter(router);
//    }
//    else
//      cLayer.setConnectionRouter(new ManhattanConnectionRouter());
  }

  /**
   * @see org.eclipse.gef.editparts.AbstractGraphicalEditPart#createFigure()
   */
  protected IFigure createFigure()
  {
    Figure f = new FreeformLayer();
    f.setLayoutManager(new FreeformLayout());
    f.setBorder(new MarginBorder(5));
    f.setBackgroundColor(ColorConstants.listBackground);
    f.setOpaque(true);
    return f;
  }
}
