/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.eclipse.editparts;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

import org.eclipse.gef.EditPolicy;
import org.eclipse.gef.editparts.AbstractGraphicalEditPart;

import be.ac.vub.cocompose.eclipse.editpolicies.CoComposeElementEditPolicy;
import be.ac.vub.cocompose.lang.Properties;
import be.ac.vub.cocompose.lang.core.ModelElement;

/**
 * Eclipse editpart controller for EclipseModelElement objects.
 * @author Dennis Wagelaar
 * @version 0.2.0, 02/12/2003
 * @since 0.2.0
 */
public abstract class ModelElementEditPart extends AbstractGraphicalEditPart
  implements PropertyChangeListener
{
  /**
   * Handles changes in properties of this. It is
   * activated through the PropertyChangeListener.
   * It updates children, source and target connections,
   * and the visuals of this based on the property
   * changed.
   * @param evt  Event which details the property change.
   * @see java.beans.PropertyChangeListener#propertyChange(java.beans.PropertyChangeEvent)
   */
  public void propertyChange(PropertyChangeEvent evt)
  {
    String id = evt.getPropertyName();
    if (id.equals(Properties.ID_NAME))
      refreshVisuals();
  }

  /**
   * Activates the editpart to listen to changes in the model.
   * @see org.eclipse.gef.EditPart#activate()
   */
  public void activate()
  {
    if (isActive())
      return;
    super.activate();
    getModelElement().addPropertyChangeListener(this);
  }

  /**
   * Makes the EditPart insensible to changes in the model
   * by removing itself from the model's list of listeners.
   * @see org.eclipse.gef.EditPart#deactivate()
   */
  public void deactivate()
  {
    if (!isActive())
      return;
    super.deactivate();
    getModelElement().removePropertyChangeListener(this);
  }

  /**
   * Installs edit policies.
   * @see org.eclipse.gef.editparts.AbstractEditPart#createEditPolicies()
   */
  protected void createEditPolicies()
  {
    installEditPolicy(EditPolicy.COMPONENT_ROLE, new CoComposeElementEditPolicy());
  }

  /**
   * Gets the model associated with this.
   * @return the model of this.
   */
  protected ModelElement getModelElement()
  {
    return (ModelElement) getModel();
  }
}
