/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 * 
 * $Id: EclipseModelFactory.java,v 1.3 2004/05/10 15:13:53 dwagelaa Exp $
 * $Log: EclipseModelFactory.java,v $
 * Revision 1.3  2004/05/10 15:13:53  dwagelaa
 * + added the ModelTransformation language element
 * + added some more CVS Id tags
 * 0 refactored some classes to use Log
 *
 */

package be.ac.vub.cocompose.eclipse.model;

import be.ac.vub.cocompose.eclipse.model.constraints.EclipseElementConstraint;
import be.ac.vub.cocompose.eclipse.model.core.EclipseConcept;
import be.ac.vub.cocompose.eclipse.model.core.EclipseImplementationGenerator;
import be.ac.vub.cocompose.eclipse.model.core.EclipseImplementationPattern;
import be.ac.vub.cocompose.eclipse.model.core.EclipseImplementationRolePart;
import be.ac.vub.cocompose.eclipse.model.core.EclipseModel;
import be.ac.vub.cocompose.eclipse.model.core.EclipseModelTransformation;
import be.ac.vub.cocompose.eclipse.model.core.EclipseRelationship;
import be.ac.vub.cocompose.eclipse.model.core.EclipseRole;
import be.ac.vub.cocompose.eclipse.model.core.EclipseSolutionPattern;
import be.ac.vub.cocompose.eclipse.model.properties.EclipseSimpleProperty;
import be.ac.vub.cocompose.lang.constraints.ElementConstraint;
import be.ac.vub.cocompose.lang.core.Concept;
import be.ac.vub.cocompose.lang.core.ImplementationGenerator;
import be.ac.vub.cocompose.lang.core.ImplementationPattern;
import be.ac.vub.cocompose.lang.core.ImplementationRolePart;
import be.ac.vub.cocompose.lang.core.Model;
import be.ac.vub.cocompose.lang.core.ModelTransformation;
import be.ac.vub.cocompose.lang.core.Relationship;
import be.ac.vub.cocompose.lang.core.Role;
import be.ac.vub.cocompose.lang.core.SolutionPattern;
import be.ac.vub.cocompose.lang.impl.DefaultModelFactory;
import be.ac.vub.cocompose.lang.properties.SimpleProperty;

/**
 * Concrete CoCompose model element factory for Eclipse elements.
 * @author Dennis Wagelaar
 * @version 0.2.10, 10/05/2004
 * @since 0.2.0
 */
public class EclipseModelFactory extends DefaultModelFactory
{
  /**
   * Creates a Model.
   * @return the Model.
   */
  public Model createModel()
  {
    return new EclipseModel();
  }

  /**
   * Creates a Relationship.
   * @return the Relationship.
   */
  public Relationship createRelationship()
  {
    return new EclipseRelationship();
  }

  /**
   * Creates a Concept.
   * @return the Concept.
   */
  public Concept createConcept()
  {
    return new EclipseConcept();
  }

  /**
   * Creates a Role.
   * @return the Role.
   */
  public Role createRole()
  {
    return new EclipseRole();
  }

  /**
   * Creates a SolutionPattern.
   * @return the SolutionPattern.
   */
  public SolutionPattern createSolutionPattern()
  {
    return new EclipseSolutionPattern();
  }

  /**
   * Creates an ImplementationGenerator.
   * @return the ImplementationGenerator.
   */
  public ImplementationGenerator createImplementationGenerator()
  {
    return new EclipseImplementationGenerator();
  }

  /**
   * Creates an ImplementationRolePart.
   * @return the ImplementationRolePart.
   */
  public ImplementationRolePart createImplementationRolePart()
  {
    return new EclipseImplementationRolePart();
  }

  /**
   * Creates an ImplementationPattern.
   * @return the ImplementationPattern.
   */
  public ImplementationPattern createImplementationPattern()
  {
    return new EclipseImplementationPattern();
  }

  /**
   * Creates a ModelTransformation.
   * @return the ModelTransformation.
   */
  public ModelTransformation createModelTransformation()
  {
    return new EclipseModelTransformation();
  }

  /**
   * Creates a SimpleProperty.
   * @return the SimpleProperty.
   */
  public SimpleProperty createSimpleProperty()
  {
    return new EclipseSimpleProperty();
  }

  /**
   * Creates an ElementConstraint.
   * @return the ElementConstraint.
   */
  public ElementConstraint createElementConstraint()
  {
    return new EclipseElementConstraint();
  }
}
