/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.eclipse.model;

import org.eclipse.jface.viewers.ICellEditorValidator;

import be.ac.vub.cocompose.lang.core.ModelElement;

/**
 * Validates CoCompose model element names.
 * @author Dennis Wagelaar
 * @version 0.2.0, 08/01/2004
 * @since 0.2.0
 */
public class NameValidator implements ICellEditorValidator
{
  /**
   * The subject to validate the name for.
   */
  private ModelElement subject = null;
  
  /**
   * Creates a NameValidator.
   * @param subject - the subject to validate.
   */
  public NameValidator(ModelElement subject)
  {
    this.subject = subject;
  }

  /**
   * @see org.eclipse.jface.viewers.ICellEditorValidator#isValid(java.lang.Object)
   */
  public String isValid(Object value)
  {
    if ((subject != null) && (value instanceof String))
    {
      if (subject.getNamespace() != null)
        if (subject.getNamespace().isRegistered((String) value))
          return ((String) value) + " is already in use within namespace " + subject.getNamespace().getName(); 
    }
    return null;
  }
}
