/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 * 
 * $Id: EclipseImplementationGenerator.java,v 1.3 2004/05/10 15:13:53 dwagelaa Exp $
 * $Log: EclipseImplementationGenerator.java,v $
 * Revision 1.3  2004/05/10 15:13:53  dwagelaa
 * + added the ModelTransformation language element
 * + added some more CVS Id tags
 * 0 refactored some classes to use Log
 *
 */

package be.ac.vub.cocompose.eclipse.model.core;

import java.util.List;
import java.util.Vector;

import org.eclipse.ui.views.properties.IPropertyDescriptor;
import org.eclipse.ui.views.properties.TextPropertyDescriptor;

import be.ac.vub.cocompose.CoCompose;
import be.ac.vub.cocompose.eclipse.model.EclipseElement;
import be.ac.vub.cocompose.eclipse.model.IPropertyDescriptorCreator;
import be.ac.vub.cocompose.eclipse.model.NameValidator;
import be.ac.vub.cocompose.lang.ModelElementException;
import be.ac.vub.cocompose.lang.Properties;
import be.ac.vub.cocompose.lang.impl.core.DefaultImplementationGenerator;
import be.ac.vub.cocompose.log.Log;

/**
 * The ImplementationGenerator language element for Eclipse.
 * @author Dennis Wagelaar
 * @version 0.2.10, 10/05/2004
 * @since 0.2.0
 */
public class EclipseImplementationGenerator extends DefaultImplementationGenerator
  implements IPropertyDescriptorCreator
{
  private Log log = CoCompose.getDefault().getLog();
  private EclipseElement element = new EclipseElement(this);

  /**
   * Creates the property descriptors.
   * @return the property descriptors.
   */
  public List createDescriptors()
  {
    List descs = new Vector();
    // name
    TextPropertyDescriptor desc = new TextPropertyDescriptor(Properties.ID_NAME, "name");
    desc.setValidator(new NameValidator(this));
    descs.add(desc);
    return descs;
  }

  /**
   * @see org.eclipse.ui.views.properties.IPropertySource#getPropertyValue(java.lang.Object)
   */
  public Object getPropertyValue(Object id)
  {
    if (Properties.ID_NAME.equals(id))
    {
      if (getName() == null)
        return new String();
      else
        return new String(getName());
    }
    return element.getPropertyValue(id);
  }

  /**
   * Sets the value of a given property with the value supplied.
   * Also fires a property change if necessary.
   * @param id - Name of the parameter to be changed.
   * @param value - Value to be set to the given parameter.
   * @see org.eclipse.ui.views.properties.IPropertySource#setPropertyValue(java.lang.Object, java.lang.Object)
   */
  public void setPropertyValue(Object id, Object value)
  {
    if (Properties.ID_NAME.equals(id))
    {
      try
      {
        setName((String) value);
      }
      catch (ModelElementException e)
      {
        log.report(e);
      }
    }
    else element.setPropertyValue(id, value);
  }

  /**
   * @see org.eclipse.ui.views.properties.IPropertySource#resetPropertyValue(java.lang.Object)
   */
  public void resetPropertyValue(Object id)
  {
    element.resetPropertyValue(id);
  }

  /////////////////////////////////////////////////////////////////////////////
  // Delegate to EclipseElement
  /////////////////////////////////////////////////////////////////////////////

  /**
   * @see org.eclipse.ui.views.properties.IPropertySource#isPropertySet(java.lang.Object)
   */
  public boolean isPropertySet(Object id)
  {
    return element.isPropertySet(id);
  }

  /**
   * @see org.eclipse.ui.views.properties.IPropertySource#getEditableValue()
   */
  public Object getEditableValue()
  {
    return element.getEditableValue();
  }

  /**
   * @see org.eclipse.ui.views.properties.IPropertySource#getPropertyDescriptors()
   */
  public IPropertyDescriptor[] getPropertyDescriptors()
  {
    return element.getPropertyDescriptors();
  }
}
