/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 * 
 * $Id: EclipseSolutionPattern.java,v 1.5 2004/05/10 14:26:23 dwagelaa Exp $
 * $Log: EclipseSolutionPattern.java,v $
 * Revision 1.5  2004/05/10 14:26:23  dwagelaa
 * worked on shared models and eclipse property sources
 *
 * Revision 1.4  2004/05/07 15:25:47  dwagelaa
 * fixed all things to compile again
 *
 * Revision 1.3  2004/05/07 14:57:53  dwagelaa
 * refactored to report errors through Log
 *
 */

package be.ac.vub.cocompose.eclipse.model.core;

import java.util.List;
import java.util.Vector;

import org.eclipse.core.internal.runtime.Assert;
import org.eclipse.ui.views.properties.IPropertyDescriptor;
import org.eclipse.ui.views.properties.TextPropertyDescriptor;

import be.ac.vub.cocompose.CoCompose;
import be.ac.vub.cocompose.eclipse.model.EclipseElement;
import be.ac.vub.cocompose.eclipse.model.IPropertyDescriptorCreator;
import be.ac.vub.cocompose.eclipse.model.NameValidator;
import be.ac.vub.cocompose.eclipse.model.datatypes.ModelElementPropertySource;
import be.ac.vub.cocompose.lang.ModelElementException;
import be.ac.vub.cocompose.lang.Properties;
import be.ac.vub.cocompose.lang.core.Model;
import be.ac.vub.cocompose.lang.impl.core.DefaultSolutionPattern;
import be.ac.vub.cocompose.log.Log;

/**
 * The SolutionPattern language element for Eclipse.
 * @author Dennis Wagelaar
 * @version 0.2.10, 06/05/2004
 * @since 0.2.0
 */
public class EclipseSolutionPattern extends DefaultSolutionPattern
  implements IPropertyDescriptorCreator
{
  private Log log = CoCompose.getDefault().getLog();
  private EclipseElement element = new EclipseElement(this);
  private ModelElementPropertySource solModelPS = null; 

  /**
   * Creates the property descriptors.
   * @return the property descriptors.
   */
  public List createDescriptors()
  {
    List descs = new Vector();
    // name
    TextPropertyDescriptor desc = new TextPropertyDescriptor(Properties.ID_NAME, "name");
    desc.setValidator(new NameValidator(this));
    descs.add(desc);
    return descs;
  }

  /**
   * @see org.eclipse.ui.views.properties.IPropertySource#getPropertyValue(java.lang.Object)
   */
  public Object getPropertyValue(Object id)
  {
    if (Properties.ID_NAME.equals(id))
    {
      if (getName() == null)
        return new String();
      else
        return new String(getName());
    }
    if (Properties.ID_SOLUTION_MODEL.equals(id))
    {
      if (solModelPS == null)
        return new Integer(0);
      else
        return solModelPS.getPropertyValue(id);
    }
    return element.getPropertyValue(id);
  }

  /**
   * Sets the value of a given property with the value supplied.
   * Also fires a property change if necessary.
   * @param id - Name of the parameter to be changed.
   * @param value - Value to be set to the given parameter.
   * @see org.eclipse.ui.views.properties.IPropertySource#setPropertyValue(java.lang.Object, java.lang.Object)
   */
  public void setPropertyValue(Object id, Object value)
  {
    if (Properties.ID_NAME.equals(id))
    {
      try
      {
        setName((String) value);
      }
      catch (ModelElementException e)
      {
        log.report(e);
      }
    }
    else if (Properties.ID_SOLUTION_MODEL.equals(id))
    {
      Assert.isNotNull(solModelPS);
      solModelPS.setPropertyValue(id, value);
      Model newElement = (Model) solModelPS.getValue();
      setSolutionModel(newElement);
    }
    else element.setPropertyValue(id, value);
  }

  /**
   * @see org.eclipse.ui.views.properties.IPropertySource#resetPropertyValue(java.lang.Object)
   */
  public void resetPropertyValue(Object id)
  {
    if (Properties.ID_SOLUTION_MODEL.equals(id))
    {
      if (solModelPS != null)
        solModelPS.resetPropertyValue(id);
      setSolutionModel(null);
    }
    else element.resetPropertyValue(id);
  }

  /**
   * Re-creates ModelElementPropertySource descriptors each time.
   * @see org.eclipse.ui.views.properties.IPropertySource#getPropertyDescriptors()
   */
  public IPropertyDescriptor[] getPropertyDescriptors()
  {
    solModelPS = new ModelElementPropertySource(this, getSolutionModel(), 
      Model.class, Properties.ID_SOLUTION_MODEL, "solution model");
    IPropertyDescriptor[] dcd = solModelPS.getPropertyDescriptors();
    IPropertyDescriptor[] d = element.getPropertyDescriptors();
    IPropertyDescriptor[] nd = new IPropertyDescriptor[d.length + dcd.length];
    for (int i = 0; i < d.length; i++)
    {
      nd[i] = d[i];
    }
    for (int i = 0; i < dcd.length; i++)
    {
      nd[i + d.length] = dcd[i];
    }
    return nd;
  }

  /////////////////////////////////////////////////////////////////////////////
  // Delegate to EclipseElement
  /////////////////////////////////////////////////////////////////////////////

  /**
   * @see org.eclipse.ui.views.properties.IPropertySource#isPropertySet(java.lang.Object)
   */
  public boolean isPropertySet(Object id)
  {
    return element.isPropertySet(id);
  }

  /**
   * @see org.eclipse.ui.views.properties.IPropertySource#getEditableValue()
   */
  public Object getEditableValue()
  {
    return element.getEditableValue();
  }
}
