/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.eclipse.model.datatypes;

import java.util.List;

import org.eclipse.core.internal.runtime.Assert;
import org.eclipse.jface.viewers.LabelProvider;

/**
 * Adapted LabelProvider that looks up the element by list index.
 * @author Dennis Wagelaar
 * @version 0.2.4, 21/01/2004
 * @since 0.2.4
 */
public class IndexedLabelProvider extends LabelProvider
{
  private List list;

  /**
   * Creates an IndexedLabelProvider.
   * @param list the list in which to look up the element.
   */
  public IndexedLabelProvider(List list)
  {
    super();
    Assert.isNotNull(list);
    this.list = list;
  }

  /**
   * Returns indexed element if the element is an Integer.
   * @param element the element list index.
   * @return toString() of the element indexed.
   * @see org.eclipse.jface.viewers.ILabelProvider#getText(java.lang.Object)
   */
  public String getText(Object element)
  {
    if (element instanceof Integer)
    {
      int index = ((Integer) element).intValue() - 1;
      if (index > -1)
      {
        Object elt = list.get(index);
        if (elt != null)
          return elt.toString();
      }
      else
        return "<<none>>";
    }
    return super.getText(element);
  }
}
