/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 * 
 * $Id: SuperimposesOnPropertySource.java,v 1.2 2004/05/10 14:26:23 dwagelaa Exp $
 * $Log: SuperimposesOnPropertySource.java,v $
 * Revision 1.2  2004/05/10 14:26:23  dwagelaa
 * worked on shared models and eclipse property sources
 *
 * Revision 1.1  2004/05/07 14:19:28  dwagelaa
 * + added model pool (shared model) support
 * + added inter-model reference support
 *
 */

package be.ac.vub.cocompose.eclipse.model.datatypes;

import be.ac.vub.cocompose.lang.core.ModelElement;
import be.ac.vub.cocompose.lang.core.RefinedElement;

/**
 * Eclipse property source for the RefinedElement SuperimposesOn relationship.
 * @author Dennis Wagelaar
 * @version 0.2.10, 10/05/2004
 * @since 0.2.10
 */
public class SuperimposesOnPropertySource extends ModelElementsPropertySource
{
  private RefinedElement subject = null;
  
  /**
   * Creates an SuperimposesOnPropertySource
   * @param subject the RefinedElement for which to edit the SuperimposesOn 
   * relationship.
   */
  public SuperimposesOnPropertySource(RefinedElement subject)
  {
    super(subject, subject.getSuperimposesOn(), RefinedElement.class);
    this.subject = subject;
  }

  /**
   * @see be.ac.vub.cocompose.eclipse.model.datatypes.ModelElementsPropertySource#removeElement(be.ac.vub.cocompose.lang.core.ModelElement)
   */
  protected void removeElement(ModelElement element)
  {
    super.removeElement(element);
    ((RefinedElement) element).removeSuperimposer(subject);
    subject.removeSuperimposesOn((RefinedElement) element);
  }

  /**
   * @see be.ac.vub.cocompose.eclipse.model.datatypes.ModelElementsPropertySource#addElement(int, be.ac.vub.cocompose.lang.core.ModelElement)
   */
  protected void addElement(int index, ModelElement element)
  {
    subject.addSuperimposesOn(index, (RefinedElement) element);
    ((RefinedElement) element).addSuperimposer(subject);
    super.addElement(index, element);
  }
}
