/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 * 
 * $Id: StreamWriter.java,v 1.4 2004/04/30 16:24:55 dwagelaa Exp $
 * $Log: StreamWriter.java,v $
 * Revision 1.4  2004/04/30 16:24:55  dwagelaa
 * + added ElementConstraint support for the CoCompose2 editor
 *
 * Revision 1.3  2004/04/28 12:23:29  dwagelaa
 * + added parsing of ImplementationPattern.content tag
 *
 */

package be.ac.vub.cocompose.io;

import java.io.UnsupportedEncodingException;
import java.io.OutputStream;

/**
 * Defines a common interface for all classes that need to write to a stream.
 * @author Dennis Wagelaar 
 * @version 0.2.0, 03/12/2003
 * @since 0.2.0
 */
public interface StreamWriter
{
  /**
   * Gets the encoding character set (e.g. "UTF-8").
   * @return the character set.
   */
  String getCharset();

  /**
   * Sets the encoding character set (e.g. "UTF-8").
   * @param charset - the character set.
   * @exception UnsupportedEncodingException - if the character set is not supported.
   */
  void setCharset(String charset) throws UnsupportedEncodingException;

  /**
   * Sets the output stream for writing.
   * @param outputStream - the output stream.
   */
  void setOutputStream(OutputStream outputStream);
}
