/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 * 
 * $Id: Concept.java,v 1.3 2004/04/26 17:39:41 dwagelaa Exp $
 * $Log: Concept.java,v $
 * Revision 1.3  2004/04/26 17:39:41  dwagelaa
 * Changed the defaultConcept property into the defaultElement property, which is a RefinedElement.
 *
 */

package be.ac.vub.cocompose.lang.core;

import java.util.List;

/**
 * The Concept language element interface.
 * @author Dennis Wagelaar
 * @version 0.2.9, 26/04/2004
 * @since 0.1.0 
 */
public interface Concept extends RefinedElement
{
  /**
   * Gets the roles of which this concept is a part.
   * @return the roles.
   */
  public List getPartOf();

  /**
   * Adds a role of which this concept is a part.
   * @param partOf the role.
   */
  public void addPartOf(Role partOf);

  /**
   * Adds a role of which this concept is a part.
   * @param index the index at which to add the element.
   * @param partOf the role.
   */
  public void addPartOf(int index, Role partOf);

  /**
   * Removes a role of which this concept is a part.
   * @param partOf the role.
   */
  public void removePartOf(Role partOf);
}
