/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 * 
 * $Id: DefaultModel.java,v 1.5 2004/05/10 14:26:23 dwagelaa Exp $
 * $Log: DefaultModel.java,v $
 * Revision 1.5  2004/05/10 14:26:23  dwagelaa
 * worked on shared models and eclipse property sources
 *
 * Revision 1.4  2004/05/07 14:19:27  dwagelaa
 * + added model pool (shared model) support
 * + added inter-model reference support
 *
 * Revision 1.3  2004/04/26 17:39:41  dwagelaa
 * Changed the defaultConcept property into the defaultElement property, which is a RefinedElement.
 *
 */

package be.ac.vub.cocompose.lang.impl.core;

import java.util.Map;

import be.ac.vub.cocompose.CoCompose;
import be.ac.vub.cocompose.lang.ModelVisitor;
import be.ac.vub.cocompose.lang.ModelElementException;
import be.ac.vub.cocompose.lang.Properties;
import be.ac.vub.cocompose.lang.core.Model;
import be.ac.vub.cocompose.lang.core.RefinedElement;
import be.ac.vub.cocompose.log.Log;

/**
 * The Model language element.
 * @author Dennis Wagelaar 
 * @version 0.2.10, 10/05/2004
 * @since 0.1.0
 */
public class DefaultModel extends DefaultNamespace implements Model 
{
  private String uri;
  private RefinedElement defaultElement = null;
  private Log log = CoCompose.getDefault().getLog();

  /**
   * Creates a DefaultModel.
   */
  public DefaultModel()
  {
    setId("0");
  }

  /**
   * Accepts a visitor.
   * @param modelVisitor The visitor to accept.
   */
  public void accept(ModelVisitor modelVisitor) throws ModelElementException 
  {
    modelVisitor.visitModel(this);
  }

  /**
   * Gets the model URI (e.g. "file://...").
   * @return the URI.
   */
  public String getUri()
  {
    return uri;
  }

  /**
   * Sets the model URI (e.g. "file://..."). Automatically derives the model
   * name as well and calls setName(). 
   * @param uri - the URI.
   */
  public void setUri(String uri)
  {
    this.uri = uri;
    firePropertyChange(Properties.ID_URI, null, uri);
    try
    {
      String name = uri.substring(uri.lastIndexOf('/') + 1);
      setName(name.substring(0, name.lastIndexOf('.')));
    }
    catch (ModelElementException e)
    {
      log.report(e);
    }
  }

  /**
   * Sets the default element for this solution pattern.
   * @param element the default element.
   */
  public void setDefaultElement(RefinedElement element)
  {
    this.defaultElement = element;
    firePropertyChange(Properties.ID_DEFAULT_ELEMENT, null, element);
  }

  /**
   * Gets the default element for this solution pattern.
   * @return the default element.
   */
  public RefinedElement getDefaultElement()
  {
    return defaultElement;
  }
  
  /**
   * Also updates the ownedIds.
   * @see be.ac.vub.cocompose.lang.core.ModelElement#setId(java.lang.String)
   */
  public void setId(String id)
  {
    Map owned = getOwnedIds();
    if (getId() != null)
      owned.remove(getId());
    super.setId(id);
    if (id != null)
      owned.put(id, this);
  }
}
