/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 */

package be.ac.vub.cocompose.log;

import java.io.PrintStream;

/**
 * Default logging class.
 * @author Dennis Wagelaar
 * @version 0.2.8, 19/04/2004
 * @since 0.2.8
 */
public class DefaultLog implements Log
{
  private int depth = 0;
  private boolean debugging = false;
  
  /**
   * @see be.ac.vub.cocompose.log.Log#log(java.lang.String, int, java.lang.Throwable)
   */
  public void log(String message, int level, Throwable exception)
  {
    if (!isDebugging() && level < WARNING)
      return;
    for (int i = 0; i < depth; i++)
    {
      message = "  " + message;
    }
    PrintStream o;
    if ((level & ERROR) == ERROR)
      o = System.err;
    else
      o = System.out;
    o.println(message);
    depth++;
  }

  /**
   * @see be.ac.vub.cocompose.log.Log#endLog()
   */
  public void endLog(int level)
  {
    if (!isDebugging() && level < WARNING)
      return;
    if (depth > 0)
      depth--;
  }

  /**
   * @see be.ac.vub.cocompose.log.Log#report(java.lang.Throwable)
   */
  public void report(Throwable e)
  {
    log(e.getMessage(), ERROR, e);
    e.printStackTrace();
  }

  /**
   * Returns true if debugging messages (OK, INFO) should be logged.
   * @return true if debugging messages should be logged.
   */
  public boolean isDebugging()
  {
    return debugging;
  }

  /**
   * Sets debugging message logging (OK, INFO).
   * @param b if true, log debug messages.
   */
  public void setDebugging(boolean b)
  {
    debugging = b;
  }
}
