/**
 * Title:        CoCompose2
 * Copyright:    Copyright (c) 2003, 2004
 * Author:       Dennis Wagelaar
 * Organisation: Vrije Universiteit Brussel
 * Description:  CoCompose2 Model Driven Design Tool
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  (See the file "COPYING" that is included with this source distribution.)
 * 
 * $Id: DeleteElement.java,v 1.3 2004/04/26 17:39:41 dwagelaa Exp $
 * $Log: DeleteElement.java,v $
 * Revision 1.3  2004/04/26 17:39:41  dwagelaa
 * Changed the defaultConcept property into the defaultElement property, which is a RefinedElement.
 *
 */

package be.ac.vub.cocompose.operations;

import java.util.List;
import java.util.Stack;
import java.util.Vector;

import be.ac.vub.cocompose.lang.DefaultTraversingModelVisitor;
import be.ac.vub.cocompose.lang.core.ModelElement;
import be.ac.vub.cocompose.lang.ModelElementException;
import be.ac.vub.cocompose.lang.core.Namespace;
import be.ac.vub.cocompose.lang.core.RefinedElement;
import be.ac.vub.cocompose.lang.core.Relationship;
import be.ac.vub.cocompose.lang.core.RelationElement;

/**
 * Deletes a ModelElement from its Namespace.
 * @author Dennis Wagelaar 
 * @version 0.2.9, 26/04/2004
 * @since 0.2.0
 */
public class DeleteElement extends DefaultTraversingModelVisitor 
{
  private Stack undeleteElements = new Stack();

  /**
   * Visits a ModelElement.
   * @param modelElement - the element to visit.
   * @exception ModelElementException
   */
  public void visitModelElement(ModelElement modelElement) throws ModelElementException
  {
    super.visitModelElement(modelElement);
    UndeleteElement undelete = new UndeleteElement();
    undelete.setDeletedElement(modelElement);
    undeleteElements.push(undelete);
    Namespace ns = modelElement.getNamespace(); 
    if (ns != null)
    {
      undelete.setElementIndex(ns.getOwnedElements().indexOf(modelElement));
      ns.removeOwnedElement(modelElement);
    }
  }

  /**
   * Visits a Relationship.
   * @param relationship - the element to visit.
   * @exception ModelElementException
   */
  public void visitRelationship(Relationship relationship) throws ModelElementException
  {
    super.visitRelationship(relationship);
    UndeleteElement undelete = (UndeleteElement) undeleteElements.peek();
    undelete.setSourceIndex(
      relationship.getSourceParticipant().getRelationships().indexOf(relationship));
    undelete.setTargetIndex(
      relationship.getTargetParticipant().getRelationships().indexOf(relationship));
    relationship.getSourceParticipant().removeRelationship(relationship);
    relationship.getTargetParticipant().removeRelationship(relationship);
  }

  /**
   * Visits a RelationElement.
   * @param relationElement - the element to visit.
   * @exception ModelElementException
   */
  public void visitRelationElement(RelationElement relationElement) throws ModelElementException
  {
    // Use copied list, since elements may be deleted during traversal
    List rs = new Vector(relationElement.getRelationships());
    for (int i = 0; i < rs.size(); i++)
    {
      ((Relationship) rs.get(i)).accept(current);
    }
    super.visitRelationElement(relationElement);
  }

  /**
   * Visits a RefinedElement.
   * @param refinedElement - the element to visit.
   * @exception ModelElementException
   */
  public void visitRefinedElement(RefinedElement refinedElement) throws ModelElementException
  {
    super.visitRefinedElement(refinedElement);
    if (refinedElement.getDefaultElementOf() != null)
    {
      refinedElement.getDefaultElementOf().setDefaultElement(null);
    }
  }

  /**
   * Undeletes the elements that were deleted.
   * @exception ModelElementException 
   */
  public void undo() throws ModelElementException 
  {
    while (!undeleteElements.isEmpty())
    {
      UndeleteElement undelete = (UndeleteElement) undeleteElements.pop();
      undelete.visit(undelete.getDeletedElement());
    }
  }
}
